from datamemorys.core.common import *
SYCM_DATAS={
    "sycm_brands_hotsales":SYCMDATA_BRANDS_HOTSALES,
    "sycm_brands_hotsearch":SYCMDATA_BRANDS_HOTSEARCH,
    "sycm_shops_hotsales":SYCMDATA_SHOPS_HOTSALES,
    "sycm_shops_hotsearch":SYCMDATA_SHOPS_HOTSEARCH,
    "sycm_items_hotsales":SYCMDATA_ITEMS_HOTSALES,
    "sycm_items_hotsearch":SYCMDATA_ITEMS_HOTSEARCH,
    "sycm_items_hotpurposes":SYCMDATA_ITEMS_PURPOSES,
    "databank_aipl_trendding":DATABANKDATA_AIPL_TRENDDING,
    "sycm_shopsources_monitor":SYCMDATA_SHOPSOURCES_MONITOR
}



from pandas import DataFrame
import pandas
import json
import requests
from datamemorys.core import SYCM_DATAS

import time
class DMDataFrame(DataFrame):
    def __init__(self,DM_tablename="",loginnNickName="",data=None,index=None,columns=None,dtype=None,copy=False,**args):
        if DM_tablename=="" and loginnNickName=="" and len(data.keys())>0:
            super().__init__(data,index,columns,dtype,copy)            
        else:
            loginnNickName=loginnNickName.split(":")[0]
            t1=time.time()
            print('开始取数')
            j=requests.get(SYCM_DATAS[DM_tablename].format(loginnNickName)).json()
            t2=time.time()
            print('从接口取数完毕一共{}行耗时{}'.format(str(len(j['data'])),str(t2-t1)))
            if j['code']!=0:            
                super().__init__()
            else:
                d=j['data']
                c=j['comments']
                ks={}
                for x in c:
                    ks[x]=c[x]['cName']                 
                df_=DataFrame(d)       
                df_=df_.rename(columns=ks)   
                for x in args:
                    if c[x]['cName'] in df_.keys():                    
                        df_=df_[df_[c[x]['cName']]==args[x]]
                super().__init__(data=df_.to_dict('records'))


            


    def Mysqlsqlstr(self,tablename):
        df=self.astype(str)
        kk=df.keys()
        d=[[df[y][x].replace("'","''") for y in kk] for x in df.index]
        d=["('"+"','".join(x)+"')" for x in d]
        sql="insert into {}(`".format(tablename)+"`,`".join(kk)+"`) values"+ ",".join(d)
        return sql


from datamemorys.datas import SYCMDataFrame
from LAC import LAC
from pandas import DataFrame
def getKeyWordsReports(loginAccName,cateid='0',device='0',priceSeg='-1',dateType='month'):
    loginAccName=loginAccName.split(":")[0]
    df=SYCMDataFrame("items_hotsearch",loginAccName)
    if cateid!='0' or cateid!=0:
        df=df[df['类目id']==str(cateid)]
    if device!='0' or device!=0:
        df=df[df['设备类型']==str(device)]
    if priceSeg!='-1' or priceSeg!=-1:
        df=df[df['价格带']==str(priceSeg)]
    if dateType!='month' :
        df=df[df['日期类型']==str(dateType)]
    lac=LAC(mode='seg')
    df['date_']=df['日期'].apply(lambda x:x.split("|")[0].split("%7C")[0])
    res=DataFrame()
    for t,itemid,d,seIpvUv,sales,uv in df[['商品名','商品id','date_','转换后搜索的Ipv人数','转换后交易额','转换后访客数']].values:
        ws=lac.run(t)
        ws=list(set(ws))        
        tdf=DataFrame({'words':ws})
        tdf['date']=d
        tdf['seIpvUv']=seIpvUv
        tdf['sales']=sales
        tdf['uv']=uv
        tdf['itemid']=itemid
        tdf['title']=t
        res=res.append(tdf) 
    return res




SYCMDATA_BRANDS_HOTSALES="http://127.0.0.1:50667/download/1/{}/7/6"
SYCMDATA_BRANDS_HOTSEARCH="http://127.0.0.1:50667/download/1/{}/7/7"
SYCMDATA_SHOPS_HOTSALES="http://127.0.0.1:50667/download/1/{}/4/1"
SYCMDATA_SHOPS_HOTSEARCH="http://127.0.0.1:50667/download/1/{}/4/2"
SYCMDATA_ITEMS_HOTSALES="http://127.0.0.1:50667/download/1/{}/5/3"
SYCMDATA_ITEMS_HOTSEARCH="http://127.0.0.1:50667/download/1/{}/5/4"
SYCMDATA_ITEMS_PURPOSES="http://127.0.0.1:50667/download/1/{}/5/5"
SYCMDATA_SHOPSOURCES_MONITOR="http://127.0.0.1:50667/download/1/{}/15/48"
SYCMDATA_SHOPS_MONITORTRENDDING="http://127.0.0.1:50667/download/1/{}/4/57"
DATABANKDATA_AIPL_TRENDDING="http://127.0.0.1:50667/download/1/{}/2/27"



from setuptools import setup

setup(
    name='datamemorys',
    version='0.0.6',
    author='lubupang',
    author_email='lbl@rrftech.com',
    url='https://www.zhihu.com/column/c_1410908597132423168',
    description=u'数字记忆插件官方数据包',
    packages=['datamemorys','datamemorys.core','datamemorys.datas','datamemorys.reports','datamemorys.utils'],
    install_requires=['lac','pandas==1.0.0']
)